@@ -4,7 +4,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use overload
   '""'     => sub { shift->to_string },
@@ -99,7 +99,7 @@ sub new {
   my $self  = bless( {}, $_[0] );
   my $input = $_[1];
 
-  return $self->_fromIP($input) if blessed($input) && $input->isa('Net::IPAM::IP');
+  return $self->_fromIP($input) if ref $input;
 
   # handle CIDR: 2001:db8::/32
   my $idx = index( $input, '/' );
@@ -178,7 +178,7 @@ sub _fromAddr {
   my $mask_n = _make_mask_n( $bits, $bits );
 
   $self->{base} = $base;
-  $self->{last} = $base->clone;
+  $self->{last} = Net::IPAM::IP->new_from_bytes( $base->bytes );
   $self->{mask} = Net::IPAM::IP->new_from_bytes($mask_n);
 
   return $self;
@@ -189,13 +189,15 @@ sub _fromAddr {
 sub _fromIP {
   my ( $self, $base ) = @_;
 
+  return unless blessed($base) && $base->isa('Net::IPAM::IP');
+
   my $bits = 32;
   $bits = 128 if $base->version == 6;
 
   my $mask_n = _make_mask_n( $bits, $bits );
 
   $self->{base} = $base;
-  $self->{last} = $base->clone;
+  $self->{last} = Net::IPAM::IP->new_from_bytes( $base->bytes );
   $self->{mask} = Net::IPAM::IP->new_from_bytes($mask_n);
 
   return $self;
